ValidateVerificationTokenResult class

Result of validating a BaxVerify access token on your backend.

Constructors

ValidateVerificationTokenResult({required bool valid, required String phone, required String projectId, required String purpose, required String requestId, required DateTime expiresAt, required DateTime issuedAt})
const
ValidateVerificationTokenResult.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
issuedAt DateTime
final
phone String
final
projectId String
final
purpose String
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valid bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited